Table of Contents

Server Properties File 🔗

You can use .deder/server.properties file to specify the server properties when client starts it.
Example

localPath=myprojects/deder/out/server/assembly.dest/out.jar
workerThreads=32
logLevel=debug
JAVA_OPTS=-javaagent:otel.jar -Dotel.service.name=deder-server -Dotel.exporter.otlp.protocol=grpc -Dotel.exporter.otlp.endpoint=http://localhost:4317

If you make changes to it, make sure you restart server manually:

deder shutdown
deder

Availabel properties:

⬅️ Files layout Repositories ➡️